@@ -393,14 +393,21 @@ class Dependencies:
             duration = self.duration(file)
             sampling_rate = self.sampling_rate(file)
         else:
-            bit_depth = channels = sampling_rate = 0
-            duration = 0.0
-            if format in define.FORMATS:
+            try:
                 path = os.path.join(root, file)
                 bit_depth = audiofile.bit_depth(path)
+                if bit_depth is None:  # pragma: nocover (non SND files)
+                    bit_depth = 0
                 channels = audiofile.channels(path)
-                duration = audiofile.duration(path)
+                duration = audiofile.duration(path, sloppy=True)
                 sampling_rate = audiofile.sampling_rate(path)
+            except FileNotFoundError:  # pragma: nocover
+                # If sox or mediafile are not installed
+                # we get a FileNotFoundError error
+                raise RuntimeError(
+                    f"sox and mediainfo have to be installed "
+                    f"to publish '{format}' media files."
+                )
 
         self._df.loc[file] = [
             archive,
