@@ -31,14 +31,12 @@ def _cached_versions(
 ) -> typing.Sequence[typing.Tuple[LooseVersion, str, Dependencies]]:
     r"""Find other cached versions of same flavor."""
 
-    df = cached(cache_root=cache_root)
+    df = cached(cache_root=cache_root, name=name)
     # If no explicit cache root is given,
     # we look into the private and shared one.
     # This fixes https://github.com/audeering/audb/issues/101
     if cache_root is None and os.path.exists(default_cache_root(shared=True)):
-        df = pd.concat((df, cached(shared=True)))
-
-    df = df[df.name == name]
+        df = pd.concat((df, cached(name=name, shared=True)))
 
     cached_versions = []
     for flavor_root, row in df.iterrows():
@@ -177,12 +175,19 @@ def _fix_media_ext(
         cur_ext = r'\.[a-zA-Z0-9]+$'  # match file extension
         new_ext = f'.{format}'
         if table.is_filewise:
-            table.df.index = table.df.index.str.replace(cur_ext, new_ext)
+            table.df.index = table.df.index.str.replace(
+                cur_ext,
+                new_ext,
+                regex=True,
+            )
         else:
-            table.df.index.set_levels(
-                table.df.index.levels[0].str.replace(cur_ext, new_ext),
-                'file',
-                inplace=True,
+            table.df.index = table.df.index.set_levels(
+                table.df.index.levels[0].str.replace(
+                    cur_ext,
+                    new_ext,
+                    regex=True,
+                ),
+                level='file',
             )
 
     audeer.run_tasks(
@@ -205,8 +210,9 @@ def _full_path(
             table.df.index = root + table.df.index
             table.df.index.name = 'file'
         elif len(table.df.index) > 0:
-            table.df.index.set_levels(
-                root + table.df.index.levels[0], 'file', inplace=True,
+            table.df.index = table.df.index.set_levels(
+                root + table.df.index.levels[0],
+                level='file',
             )
 
 
